@@ -68,9 +68,17 @@ OC.L10N.register(
     "A <strong>board, list or card</strong> was changed" : "לוח, רשימה או כרטיס שונה",
     "A <strong>comment</strong> was created on a card" : "נוצרה <strong>הערה</strong> על כרטיס",
     "A <strong>card description</strong> has been changed" : "תיאור הכרטיס שונה",
+    "The file was uploaded" : "הקובץ הועלה",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
+    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
+    "No file was uploaded" : "לא הועלה קובץ",
+    "Missing a temporary folder" : "חסרה תיקייה זמנית",
+    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
+    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
+    "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
     "Upcoming cards" : "כרטיסים עתידיים",
     "Load more" : "לטעון עוד",
-    "Personal" : "אישי",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "הכרטיס \"%s\" שב־„%s” הוקצה אליך על ידי %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} has assigned the card {deck-card} on {deck-board} to you.",
     "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
@@ -83,45 +91,34 @@ OC.L10N.register(
     "Action needed" : "נדרשת פעולה",
     "Later" : "מאוחר יותר",
     "copy" : "עותק",
-    "To do" : "לעשות",
-    "Doing" : "בביצוע",
+    "To Do" : "מטלות",
     "Done" : "הסתיים",
-    "Example Task 3" : "משימה לדוגמה 3",
-    "Example Task 2" : "משימה לדוגמה 2",
-    "Example Task 1" : "משימה לדוגמה 1",
-    "The file was uploaded" : "הקובץ הועלה",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
-    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
-    "No file was uploaded" : "לא הועלה קובץ",
-    "Missing a temporary folder" : "חסרה תיקייה זמנית",
-    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
-    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
-    "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
+    "Attachments" : "קבצים מצורפים",
+    "File" : "קובץ",
     "Card not found" : "כרטיס לא נמצא",
     "Path is already shared with this card" : "הנתיב כבר משותף עם הכרטיס הזה",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך שגוי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Personal planning and team project organization" : "ארגון אישי וקבוצתי של מיזמים",
     "Add board" : "הוספת לוח",
+    "Card details" : "פרטי הכרטיס",
     "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
     "Search by board title" : "חיפוש לפי כותרת לו",
     "Select board" : "בחירת לוח",
-    "Move card to another board" : "העברת כרטיס ללוח אחר",
     "Select a board" : "נא לבחור לוח",
     "No lists available" : "אין רשימות זמינות",
     "Select a list" : "בחר רשימה",
     "Move card" : "העברת כרטיס",
-    "Cancel" : "ביטול",
-    "Select a card" : "נא לבחור כרטיס",
     "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
     "Link to card" : "קישור לכרטיס",
+    "Select a card" : "נא לבחור כרטיס",
+    "Cancel" : "ביטול",
+    "This board is read only" : "הלוח הזה הוא לקריאה בלבד",
+    "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "File already exists" : "הקובץ כבר קיים",
     "A file with the name {filename} already exists." : "כבר קיים קובץ עם השם {filename}.",
     "Do you want to overwrite it?" : "לשכתב עליו?",
     "Overwrite file" : "דריסת קובץ",
     "Keep existing file" : "לשמור על הקובץ הקיים",
-    "This board is read only" : "הלוח הזה הוא לקריאה בלבד",
-    "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "Add card" : "הוספת כרטיס",
     "Archived cards" : "כרטיסים בארכיון",
     "Add list" : "הוספת רשימה",
@@ -154,6 +151,8 @@ OC.L10N.register(
     "Deleted lists" : "רשימות שנמחקו",
     "Undo" : "ביטול",
     "Deleted cards" : "כרטיסים שנמחקו",
+    "Failed to create share with {displayName}" : "יצירת השיתוף עם {displayName} נכשלה",
+    "Transfer" : "העברה",
     "No participants found" : "לא נמצאו משתתפים",
     "Board owner" : "בעלות על הלוח",
     "(Group)" : "(קבוצה)",
@@ -162,20 +161,20 @@ OC.L10N.register(
     "Can manage" : "הרשאת ניהול",
     "Owner" : "בעלות",
     "Delete" : "מחיקה",
-    "Failed to create share with {displayName}" : "יצירת השיתוף עם {displayName} נכשלה",
-    "Transfer" : "העברה",
+    "List deleted" : "הרשימה נמחקה",
     "Archive all cards" : "ארכיב את כל הכרטיסים",
     "Delete list" : "מחיקת רשימה",
     "Archive all cards in this list" : "ארכיב את כל הכרטיסים ברשימה זו",
     "Add a new card" : "הוספת כרטיס חדש",
     "Card name" : "שם כרטיס",
-    "List deleted" : "הרשימה נמחקה",
+    "title and color value must be provided" : "יש לספק כותרת וערך צבע",
     "Edit" : "עריכה",
     "Add a new tag" : "הוספת תגית חדשה",
-    "title and color value must be provided" : "יש לספק כותרת וערך צבע",
     "Board name" : "שם הלוח",
     "Members" : "חברים",
     "Assign a user to this card…" : "הקצאת משתמש לכרטיס זה…",
+    "File to share" : "קובץ לשיתוף",
+    "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Upload new files" : "העלאת קבצים חדשים",
     "Share from Files" : "שיתוף מקבצים",
     "Add this attachment" : "הוספת קובץ מצורף זה",
@@ -183,23 +182,21 @@ OC.L10N.register(
     "Download" : "הורדה",
     "Delete Attachment" : "מחיקת קובץ מצורף",
     "Restore Attachment" : "שחזור קובץ מצורף",
-    "File to share" : "קובץ לשיתוף",
-    "Invalid path selected" : "הנתיב שנבחר שגוי",
-    "Open in sidebar view" : "פתח בתצוגת סרגל הצד",
-    "Open in bigger view" : "פתח בתצוגה גדולה יותר",
-    "Attachments" : "קבצים מצורפים",
-    "Comments" : "תגובות",
     "Modified" : "מועד שינוי",
     "Created" : "מועד היצירה",
     "The title cannot be empty." : "הכותרת לא יכולה להיות ריקה.",
+    "Open in sidebar view" : "פתח בתצוגת סרגל הצד",
+    "Open in bigger view" : "פתח בתצוגה גדולה יותר",
+    "Comments" : "תגובות",
     "No comments yet. Begin the discussion!" : "אין עדיין הערות. אפשר להתחיל לדון!",
-    "Save" : "שמור",
     "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
     "The comment cannot be longer than 1000 characters." : "אורך ההערה לא יכול לחצות את רף 1000 התווים.",
+    "Save" : "שמור",
+    "Created:" : "מועד היצירה:",
     "In reply to" : "בתגובה אל",
     "Reply" : "תגובה",
     "Update" : "עדכון",
-    "Created:" : "מועד היצירה:",
+    "Write a description …" : "כתוב תיאור ...",
     "Description" : "תיאור",
     "(Unsaved)" : "(לא נשמר)",
     "(Saving…)" : "(מתבצעת שמירה…)",
@@ -207,20 +204,19 @@ OC.L10N.register(
     "Edit description" : "עריכת תיאור",
     "View description" : "הצגת תיאור",
     "Add Attachment" : "הוספת קובץ מצורף",
-    "Write a description …" : "כתוב תיאור ...",
     "Choose attachment" : "בחירת קובץ מצורף",
+    "Select Date" : "בחירת תאריך",
     "Set a due date" : "הגדרת תאריך יעד",
     "Remove due date" : "הסרת מועד התפוגה",
     "Unarchive card" : "הוצאת הכרטיס מהארכיון",
     "Archive card" : "העברת כרטיס לארכיון",
-    "Select Date" : "בחירת תאריך",
     "Assign a tag to this card…" : "הקצאת תגית לכרטיס זה…",
     "(group)" : "(קבוצה)",
-    "Card details" : "פרטי הכרטיס",
+    "Card deleted" : "הכרטיס נמחק",
+    "Edit title" : "עריכת כותרת",
     "Assign to me" : "הקצאה אלי",
     "Unassign myself" : "לבטל את הקצאת עצמי",
     "Delete card" : "מחיקת כרטיס לארכיון",
-    "Card deleted" : "הכרטיס נמחק",
     "seconds ago" : "לפני מספר שניות",
     "Keyboard shortcuts" : "קיצורי מקלדת",
     "Keyboard shortcut" : "קיצור מקלדת",
@@ -232,6 +228,13 @@ OC.L10N.register(
     "Shared with you" : "משותף אתך",
     "Use bigger card view" : "להשתמש בתצוגת כרטיסים גדולה יותר",
     "Show boards in calendar/tasks" : "הצג הלוחות בלוח השנה/המשימות",
+    "Cancel edit" : "בטל עריכה",
+    "Board {0} deleted" : "הלוח {0} נמחק",
+    "All cards" : "כל הכרטיסים",
+    "Only assigned cards" : "רק כרטיסים שהוקצו",
+    "No reminder" : "אין תזכורת",
+    "An error occurred" : "אירעה שגיאה",
+    "Delete the board?" : "למחוק את הלוח הזה?",
     "Board details" : "פרטי לוח",
     "Edit board" : "עריכת לוח",
     "Clone board" : "שכפל את הלוח",
@@ -240,15 +243,11 @@ OC.L10N.register(
     "Turn on due date reminders" : "הפעל תזכורות לתאריך היעד",
     "Turn off due date reminders" : "השבת תזכורות לתאריך היעד",
     "Due date reminders" : "תזכורות לתאריך יעד",
-    "All cards" : "כל הכרטיסים",
     "Assigned cards" : "כרטיסים שהוקצו",
     "No notifications" : "אין התראות",
     "Delete board" : "מחק לוח",
-    "Board {0} deleted" : "הלוח {0} נמחק",
-    "Only assigned cards" : "רק כרטיסים שהוקצו",
-    "No reminder" : "אין תזכורת",
-    "An error occurred" : "אירעה שגיאה",
-    "Delete the board?" : "למחוק את הלוח הזה?",
+    "Advanced options" : "אפשרויות מתקדמות",
+    "Export" : "ייצוא",
     "Loading filtered view" : "טוען תצוגה מסוננת",
     "Today" : "היום",
     "Tomorrow" : "מחר",
@@ -263,20 +262,17 @@ OC.L10N.register(
     "Something went wrong" : "משהו השתבש",
     "Failed to upload {name}" : "העלאת {name} נכשלה",
     "Maximum file size of {size} exceeded" : "גודל הקבצים המרבי {size} הושג",
+    "Due date" : "מועד יעד",
     "Error creating the share" : "שגיאה ביצירת השיתוף",
     "Share with a Deck card" : "שיתוף עם כרטיס חפיסה",
     "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
     "Share" : "שיתוף",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>תיאור של כרטיס</strong> בתוך יישומון החבילה נערך",
-    "Timeline" : "ציר זמן",
-    "Share board with a user, group or circle …" : "שיתוף לוח עם משתמש, קבוצה או מעגל…",
-    "Searching for users, groups and circles …" : "מחפש משתמשים, קבוצות, ומעגלים ...",
-    "(Circle)" : "(מעגל)",
-    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים",
-    "Next week" : "השבוע הבא",
-    "Next month" : "החודש הבא",
-    "List is empty" : "הרשימה ריקה",
-    "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם."
+    "Personal" : "אישי",
+    "To do" : "לעשות",
+    "Doing" : "בביצוע",
+    "Example Task 3" : "משימה לדוגמה 3",
+    "Example Task 2" : "משימה לדוגמה 2",
+    "Example Task 1" : "משימה לדוגמה 1",
+    "Move card to another board" : "העברת כרטיס ללוח אחר"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
