@@ -72,6 +72,15 @@ OC.L10N.register(
     "A <strong>board, list or card</strong> was changed" : "<strong>ボード、リストまたはカードは変更されました",
     "A <strong>comment</strong> was created on a card" : "カードに<strong>コメント</strong>が作成されたとき",
     "A <strong>card description</strong> has been changed" : "<strong>カード説明</strong>が変更されました",
+    "The file was uploaded" : "ファイルがアップロードされました",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブを超えています",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
+    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
+    "No file was uploaded" : "ファイルはアップロードされませんでした",
+    "Missing a temporary folder" : "一時領域フォルダーがありません",
+    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
+    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
+    "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
     "Cards due today" : "今日の期限切れのカード",
     "Cards due tomorrow" : "明日の期限切れのカード",
     "Upcoming cards" : "今後のカード",
@@ -101,23 +110,16 @@ OC.L10N.register(
     "To Do" : "To Do",
     "In Progress" : "進行中",
     "Done" : "完了",
-    "The file was uploaded" : "ファイルがアップロードされました",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブを超えています",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
-    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
-    "No file was uploaded" : "ファイルはアップロードされませんでした",
-    "Missing a temporary folder" : "一時領域フォルダーがありません",
-    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
-    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
-    "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
     "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "このコメントは、%s 文字以上含まれています。\n%sという名前で、カードに添付ファイルとして追加しました。\n次のURLでアクセス可能です: %s",
+    "Attachments" : "添付ファイル",
+    "File" : "ファイル",
     "Card not found" : "カードが見つかりません",
     "Path is already shared with this card" : "パスは既にこのカードで共有されています",
     "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
     "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合された、チームのための個人計画とプロジェクトの組織化を目的としたカンバンスタイルのオーガナイズツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 追加のメモをマークダウン形式で書き留める\n- 🔖 より詳細な分類のために追加のラベルを割り当てる\n- 👥 チーム、友達、家族と共有\n- 📎 ファイルを添付し、マークダウンの説明に埋め込む\n- 💬 コメントを使用してチームで話し合う\n- ⚡ アクティビティストリームで変更を追跡する\n- 🚀 プロジェクトを整理する",
-    "Card details" : "カード詳細",
     "Add board" : "ボードを追加",
+    "Card details" : "カード詳細",
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
     "Search by board title" : "ボードのタイトルで検索",
     "Select board" : "ボードを選択",
@@ -125,17 +127,17 @@ OC.L10N.register(
     "No lists available" : "利用可能なリストはありません",
     "Select a list" : "リストを選択",
     "Move card" : "カードの移動",
-    "Select a card" : "カードを選択",
-    "Cancel" : "キャンセル",
     "Select the card to link to a project" : "プロジェクトにリンクするカードを選択",
     "Link to card" : "カードへリンク",
+    "Select a card" : "カードを選択",
+    "Cancel" : "キャンセル",
+    "This board is read only" : "このボードは読み込みのみです",
+    "Drop your files to upload" : "アップロードするファイルをドロップしてください",
     "File already exists" : "ファイルはすでに存在します",
     "A file with the name {filename} already exists." : "そのファイル名 {filename}はすでに存在します。",
     "Do you want to overwrite it?" : "上書きしますか？",
     "Overwrite file" : "ファイルを上書き",
     "Keep existing file" : "既存のファイルを残す",
-    "This board is read only" : "このボードは読み込みのみです",
-    "Drop your files to upload" : "アップロードするファイルをドロップしてください",
     "Add card" : "カードを追加",
     "Archived cards" : "カードをアーカイブ",
     "Add list" : "リストを追加",
@@ -176,6 +178,12 @@ OC.L10N.register(
     "Deleted lists" : "削除済みリスト",
     "Undo" : "元に戻す",
     "Deleted cards" : "削除済みのカード",
+    "Failed to create share with {displayName}" : "{displayName}との共有の作成に失敗しました",
+    "Are you sure you want to transfer the board {title} to {user}?" : "本当にボード {title} を {user} に転送しますか？",
+    "Transfer the board." : "ボードを転送します。",
+    "Transfer" : "転送",
+    "The board has been transferred to {user}" : "ボードが {user} に転送されました。",
+    "Failed to transfer the board to {user}" : "{user} へのボードの転送に失敗しました",
     "Share board with a user, group or team …" : "ユーザー、グループ、チームでボードを共有 ...",
     "Searching for users, groups and teams …" : "ユーザー、グループ、チームの検索中...",
     "No participants found" : "参加者が見つかりません",
@@ -187,12 +195,7 @@ OC.L10N.register(
     "Can manage" : "管理可能",
     "Owner" : "所有者",
     "Delete" : "削除",
-    "Failed to create share with {displayName}" : "{displayName}との共有の作成に失敗しました",
-    "Are you sure you want to transfer the board {title} to {user}?" : "本当にボード {title} を {user} に転送しますか？",
-    "Transfer the board." : "ボードを転送します。",
-    "Transfer" : "転送",
-    "The board has been transferred to {user}" : "ボードが {user} に転送されました。",
-    "Failed to transfer the board to {user}" : "{user} へのボードの転送に失敗しました",
+    "List deleted" : "リストが削除されました",
     "Edit list title" : "リストタイトルを編集する",
     "Archive all cards" : "すべてのカードをアーカイブする",
     "Unarchive all cards" : "全てのカードをアーカイブ解除",
@@ -201,15 +204,16 @@ OC.L10N.register(
     "Unarchive all cards in this list" : "このリスト内の全てのカードのアーカイブを解除する",
     "Add a new card" : "新しいカードを追加",
     "Card name" : "カード名",
-    "List deleted" : "リストが削除されました",
+    "title and color value must be provided" : "タイトルと色の値を指定する必要があります",
     "Edit" : "編集",
     "Add a new tag" : "新しいタグを追加",
-    "title and color value must be provided" : "タイトルと色の値を指定する必要があります",
     "Board name" : "ボード名",
     "Members" : "メンバー",
     "Assign to users/groups/team" : "ユーザー/グループ/チームに割り当てる",
     "Assign a user to this card…" : "このカードをユーザーに割り当てる…",
     "Select a user to assign to this card…" : "このカードに割り当てるユーザーを選択してください。",
+    "File to share" : "共有するファイル",
+    "Invalid path selected" : "無効なパスが選択されました",
     "Upload new files" : "新しいファイルをアップロード",
     "Share from Files" : "ファイルから共有",
     "Pending share" : "共有を保留中",
@@ -219,25 +223,23 @@ OC.L10N.register(
     "Remove attachment" : "添付ファイルを削除",
     "Delete Attachment" : "添付ファイルを削除",
     "Restore Attachment" : "添付ファイルを復元",
-    "File to share" : "共有するファイル",
-    "Invalid path selected" : "無効なパスが選択されました",
-    "Open in sidebar view" : "サイドバービューで開く",
-    "Open in bigger view" : "拡大表示で開く",
-    "Attachments" : "添付ファイル",
-    "Comments" : "コメント",
     "Modified" : "更新日時",
     "Created" : "作成時刻",
     "The title cannot be empty." : "タイトルを空にすることはできません。",
-    "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
+    "Open in sidebar view" : "サイドバービューで開く",
+    "Open in bigger view" : "拡大表示で開く",
+    "Comments" : "コメント",
     "Failed to load comments" : "コメントの読み込みに失敗しました",
-    "Save" : "保存",
+    "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
     "The comment cannot be empty." : "コメントを空にすることはできません。",
     "The comment cannot be longer than 1000 characters." : "コメントは1000文字を超えることはできません。",
+    "Save" : "保存",
+    "Created:" : "作成:",
     "In reply to" : "返信",
     "Cancel reply" : "返信をキャンセル",
     "Reply" : "返信",
     "Update" : "更新",
-    "Created:" : "作成:",
+    "Write a description …" : "説明を書く…",
     "Description" : "説明",
     "(Unsaved)" : "(未保存)",
     "(Saving…)" : "(保存中…)",
@@ -245,8 +247,16 @@ OC.L10N.register(
     "Edit description" : "説明を編集",
     "View description" : "説明を表示",
     "Add Attachment" : "添付ファイルを追加",
-    "Write a description …" : "説明を書く…",
     "Choose attachment" : "添付ファイルを選択",
+    "Select Date" : "日付を選択",
+    "Later today – {timeLocale}" : "今日この後 – {timeLocale}",
+    "Set due date for later today" : "期限を今日中に設定する",
+    "Tomorrow – {timeLocale}" : "明日 – {timeLocale}",
+    "Set due date for tomorrow" : "期限を明日の設定する",
+    "This weekend – {timeLocale}" : "今週末 – {timeLocale}",
+    "Set due date for this weekend" : "期限を今週の週末に設定する",
+    "Next week – {timeLocale}" : "来週 – {timeLocale}",
+    "Set due date for next week" : "期限を次の週の設定する",
     "Assign a due date to this card…" : "このカードの期限を割り当てる",
     "Set a due date" : "期限を設定",
     "Add due date" : "期限日を追加する",
@@ -257,25 +267,19 @@ OC.L10N.register(
     "Not done" : "まだ完成していません",
     "Unarchive card" : "カードのアーカイブを解除する",
     "Archive card" : "カードをアーカイブ",
-    "Select Date" : "日付を選択",
-    "Set due date for later today" : "期限を今日中に設定する",
-    "Set due date for tomorrow" : "期限を明日の設定する",
-    "Set due date for this weekend" : "期限を今週の週末に設定する",
-    "Set due date for next week" : "期限を次の週の設定する",
     "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
     "Select or create a tag…" : "タグを選択または作成する",
     "Create a new tag:" : "新しいタグを作成:",
     "(group)" : "(グループ)",
-    "Next week – {timeLocale}" : "来週 – {timeLocale}",
-    "Todo items" : "Todo項目",
     "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
+    "Todo items" : "Todo項目",
     "Edit card title" : "カードタイトルを編集する",
+    "Card deleted" : "カードが削除されました",
     "Edit title" : "タイトルを編集",
     "Assign to me" : "自分に割り当てる",
     "Unassign myself" : "自分への割り当てを解除",
     "Mark as not done" : "未完成のマーク",
     "Delete card" : "カードを削除する",
-    "Card deleted" : "カードが削除されました",
     "seconds ago" : "数秒前",
     "Keyboard shortcuts" : "キーボードショートカット",
     "Boost your productivity using Deck with keyboard shortcuts." : "キーボードショートカットを使って、あなたのDeckの生産性を向上させましょう。",
@@ -313,6 +317,13 @@ OC.L10N.register(
     "Limit board creation to some groups" : "ボード作成は一部のグループに制限する",
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "これらのグループ以外のユーザーは、独自のボードを作成することはできませんが、共有されているボードで作業することはできます。",
     "Cancel edit" : "編集をキャンセル",
+    "Board {0} deleted" : "ボード {0} 削除済み",
+    "All cards" : "すべてのカード",
+    "Only assigned cards" : "割り当てられたカードのみ",
+    "No reminder" : "リマインダーなし",
+    "An error occurred" : "エラーが発生しました",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "ボード{title}を削除しますか? これにより、アーカイブされたカードを含むこのボードのすべてのデータが削除されます。",
+    "Delete the board?" : "ボードを削除しますか？",
     "Board details" : "ボードの詳細",
     "Edit board" : "ボードを編集",
     "Clone board" : "ボードを複製",
@@ -322,19 +333,14 @@ OC.L10N.register(
     "Turn on due date reminders" : "期日のリマインダーをオンにする",
     "Turn off due date reminders" : "期日のリマインダーをオフにする",
     "Due date reminders" : "期日のリマインダー",
-    "All cards" : "すべてのカード",
     "Assigned cards" : "割り当てられたカード",
     "No notifications" : "非通知",
     "Delete board" : "ボードを削除",
-    "Board {0} deleted" : "ボード {0} 削除済み",
-    "Only assigned cards" : "割り当てられたカードのみ",
-    "No reminder" : "リマインダーなし",
-    "An error occurred" : "エラーが発生しました",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "ボード{title}を削除しますか? これにより、アーカイブされたカードを含むこのボードのすべてのデータが削除されます。",
-    "Delete the board?" : "ボードを削除しますか？",
     "Clone cards" : "カードを複製",
     "Advanced options" : "詳細オプション",
     "Clone" : "複製",
+    "Export as CSV" : "CSV にエクスポート",
+    "Export" : "エクスポート",
     "Loading filtered view" : "フィルタされたビューを読み込み中",
     "Today" : "今日",
     "Tomorrow" : "明日",
@@ -342,14 +348,15 @@ OC.L10N.register(
     "Search for {searchQuery} in all boards" : "すべてのボードで{searchQuery}を検索します",
     "No results found" : "結果が見つかりません",
     "Deck board {name}\n* Last modified on {lastMod}" : "デッキボード{name}\n最終更新日：{lastMod}",
-    "{stack} in {board}" : "{board} 内の {stack}",
-    "Click to expand description" : "説明を展開するにはクリックしてください",
     "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 作成: {created}\n* 最終変更: {lastMod}\n* {nbAttachments} 添付ファイル\n* {nbComments} コメント",
     "{nbCards} cards" : "{nbCards} カード",
+    "Due on {date}" : "期間{date}",
+    "{stack} in {board}" : "{board} 内の {stack}",
+    "Click to expand description" : "説明を展開するにはクリックしてください",
     "Click to expand comment" : "コメントを展開するにはクリックしてください",
+    "Create card" : "カードを作成",
     "Create a new card" : "新しいカードを作成する",
     "Card title" : "カードのタイトル",
-    "Create card" : "カードを作成",
     "Creating the new card …" : "新しいカードを作成しています...",
     "Card \"{card}\" was added to \"{board}\"" : "カード \"{card}\" が \"{board}\" に追加されました",
     "Open card" : "カードを開く",
@@ -359,10 +366,6 @@ OC.L10N.register(
     "upcoming cards tomorrow" : "明日の予定のカード",
     "upcoming cards" : "今後のカード",
     "New card" : "新しいカード",
-    "Due on {date}" : "期間{date}",
-    "This weekend – {timeLocale}" : "今週末 – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "明日 – {timeLocale}",
-    "Later today – {timeLocale}" : "今日この後 – {timeLocale}",
     "Link to a board" : "ボードへのリンク",
     "Link to a card" : "カードへリンク",
     "Create a card" : "カードを作成",
@@ -370,6 +373,7 @@ OC.L10N.register(
     "Something went wrong" : "何かがおかしいです",
     "Failed to upload {name}" : "{name}のアップロードに失敗しました",
     "Maximum file size of {size} exceeded" : "最大ファイルサイズ（{size}）を超えています",
+    "Due date" : "期限",
     "Error creating the share" : "共有の作成中にエラーが発生しました",
     "Share with a Deck card" : "デッキのカードで共有する",
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
@@ -380,7 +384,6 @@ OC.L10N.register(
     "Example Task 3" : "タスク3の例",
     "Example Task 2" : "タスク2の例",
     "Example Task 1" : "タスク1の例",
-    "Move card to another board" : "カードを他のボードに移動",
-    "Filter by completed" : "完成したものをフィルターする"
+    "Move card to another board" : "カードを他のボードに移動"
 },
 "nplurals=1; plural=0;");
