@@ -1,13 +1,14 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Udmawan",
-    "Finished" : "Immed",
-    "Done" : "Immed",
     "The file was uploaded" : "Ulac afaylu yettwaznen",
     "The file was only partially uploaded" : "Afaylu, cwiṭ kan i yettwaznen segs",
     "No file was uploaded" : "Ulac afaylu i d-yettwasulin",
     "Missing a temporary folder" : "Ixuṣ ukaram akudan",
+    "Finished" : "Immed",
+    "Done" : "Immed",
+    "Attachments" : "Ticeqqufin",
+    "File" : "Afaylu",
     "Cancel" : "Sefsex",
     "Open" : "Ldi",
     "Completed" : "Yemmed",
@@ -19,17 +20,18 @@ OC.L10N.register(
     "Delete" : "Kkes",
     "Edit" : "Ẓreg",
     "Download" : "Sider",
-    "Attachments" : "Ticeqqufin",
-    "Comments" : "Commentaires",
     "Modified" : "Yettwabeddel",
     "Created" : "Yettwarna.",
+    "Comments" : "Commentaires",
     "Save" : "Sekles",
     "Cancel reply" : "Semmet tiririt.",
     "Reply" : "Err",
     "Search" : "Nadi",
+    "Cancel edit" : "Sefsex aseẓreg",
     "No notifications" : "Ulac tisezmal",
     "Today" : "Ass-a",
     "Close" : "Mdel",
-    "Share" : "Bḍu"
+    "Share" : "Bḍu",
+    "Personal" : "Udmawan"
 },
 "nplurals=2; plural=(n != 1);");
