@@ -1,10 +1,9 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
-    "Done" : "Done",
     "No file was uploaded" : "ವರ್ಗಾವಣೆಗೆ ﻿ಯಾವುದೇ ಕಡತಗಳು ಕಂಡುಬಂದಿಲ್ಲ",
     "Missing a temporary folder" : "ತಾತ್ಕಾಲಿಕ ಕಡತಕೋಶ ದೊರೆಕುತ್ತಿಲ್ಲ",
+    "Done" : "Done",
     "Cancel" : "﻿ರದ್ದು",
     "Open" : "ತೆರೆಯಿರಿ",
     "Sharing" : "﻿ಹಂಚಿಕೆ",
@@ -18,8 +17,10 @@ OC.L10N.register(
     "Save" : "﻿ಉಳಿಸಿ",
     "Search" : "Search",
     "Shared with you" : "Shared with you",
+    "Export" : "ರಫ್ತು",
     "Today" : "Today",
     "Close" : "ಮುಚ್ಚು",
-    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ"
+    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
+    "Personal" : "﻿ವೈಯಕ್ತಿಕ"
 },
 "nplurals=2; plural=(n > 1);");
