@@ -1,11 +1,11 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "ສ່ວນບຸກຄົນ",
-    "Finished" : "ສຳເລັດ",
-    "Done" : "ສໍາເລັດ",
     "The file was uploaded" : "ຟາຍຖຶກອັບໂຫລດສຳເລັດ",
     "No file was uploaded" : "ບໍ່ມີການອັບໂຫລດຟາຍ",
+    "Finished" : "ສຳເລັດ",
+    "Done" : "ສໍາເລັດ",
+    "File" : "ຟາຍ",
     "Cancel" : "ຍົກເລີກ",
     "Completed" : "ສຳເລັດ",
     "Details" : "ລາຍລະອຽດ",
@@ -18,8 +18,8 @@ OC.L10N.register(
     "Delete" : "ລຶບ",
     "Edit" : "ແກ້ໄຂ",
     "Download" : "ດາວໂຫລດ",
-    "Comments" : "ຄໍາເຫັນ",
     "Modified" : "\"{name}\" ແມ່ນຊື່ໄຟລ໌ທີ່ບໍ່ຖືກຕ້ອງ.",
+    "Comments" : "ຄໍາເຫັນ",
     "Save" : "ບັນທຶກ",
     "seconds ago" : "ວິນາທີຜ່ານມາ",
     "Search" : "ຄົ້ນຫາ",
@@ -27,6 +27,7 @@ OC.L10N.register(
     "No notifications" : "ບໍ່ມີການແຈ້ງເຕືອນ",
     "Today" : "ມື້ນີ້",
     "Close" : "ປິດ",
-    "Share" : "ແບ່ງປັນ"
+    "Share" : "ແບ່ງປັນ",
+    "Personal" : "ສ່ວນບຸກຄົນ"
 },
 "nplurals=1; plural=0;");
