@@ -2,20 +2,19 @@ OC.L10N.register(
     "deck",
     {
     "Deck" : "Shto paisjen U2F",
-    "Personal" : "Personale",
+    "The file was uploaded" : "Skedari u ngarkua",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
+    "No file was uploaded" : "S’u ngarkua kartelë",
+    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
     "%s on %s" : "%s në %s",
     "Finished" : "Përfunduar",
     "To review" : "Për rishikim",
     "Action needed" : "Nevoitet veprim",
     "Later" : "Më vonë",
     "copy" : "kopjo",
-    "To do" : "Për t'u bërë",
-    "Doing" : "Duke e bërë",
     "Done" : "Përfunduar",
-    "The file was uploaded" : "Skedari u ngarkua",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
-    "No file was uploaded" : "S’u ngarkua kartelë",
-    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
+    "Attachments" : "Bashkangjitjet",
+    "File" : "Skedar ",
     "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
     "Cancel" : "Anullo",
     "File already exists" : "Skedari ekziston tashmë",
@@ -37,18 +36,17 @@ OC.L10N.register(
     "Edit" : "Edito",
     "Members" : "Anëtar",
     "Download" : "Shkarko",
-    "Attachments" : "Bashkangjitjet",
-    "Comments" : "Komentet",
     "Modified" : "Modifikuar ",
     "Created" : "U krijua",
+    "Comments" : "Komentet",
     "Save" : "Ruaj",
+    "Created:" : "Krijuar:",
     "Reply" : "Përgjigju",
     "Update" : "Përditëso",
-    "Created:" : "Krijuar:",
     "Description" : "Përshkrim",
     "Formatting help" : "Ndihmë formatimi",
-    "Remove due date" : "Hiq datën e mbarimit",
     "Select Date" : "Zgjidhni Datën",
+    "Remove due date" : "Hiq datën e mbarimit",
     "(group)" : "(grup)",
     "seconds ago" : "sekonda më parë",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
@@ -63,10 +61,15 @@ OC.L10N.register(
     "Archive board" : "Arkivo bordin",
     "No notifications" : "Asnjë njofim",
     "Delete board" : "Fshij bordin",
+    "Advanced options" : "Opsione të avancuara",
+    "Export" : "Eksport",
     "Today" : "Sot",
     "Tomorrow" : "Nesër",
     "Close" : "Mbylleni",
+    "Due date" : "Data e vendosur",
     "Share" : "Shpërndaje",
-    "List is empty" : "Lista është bosh"
+    "Personal" : "Personale",
+    "To do" : "Për t'u bërë",
+    "Doing" : "Duke e bërë"
 },
 "nplurals=2; plural=(n != 1);");
